/*
*   $Id: CCMerchantCustom.h,v 1.6 1998/03/31 21:00:52 grass Exp $
*
*   System     :   Merchant Connection Kit
*
*   Author     :   CYCH Development staff
*   Description:   Header for Module of **OPTIONALLY** customizable functions 
*                  shared by MCK CGI scripts
*   Notes      :   Each merchant should have a copy of this which is customized
*                  to integrate with the merchant storefront
*
*                         COPYRIGHT NOTICE
*
*   The contents of this file is protected under the United States
*   copyright laws as an unpublished work, and is confidential and
*   proprietary to CyberCash, Inc.  Its use or disclosure in whole or in
*   part without the expressed written permission of CyberCash, Inc. is
*   prohibited.
*
*   (c) Copyright 1993-98 by CyberCash, Inc.  All rights reserved.
*
*/                                                                       

#ifndef _CCMERCHANTCUSTOM_H_
#define _CCMERCHANTCUSTOM_H_

#ifdef __cplusplus
extern "C" {
#endif
#include "CCNVlist.h"

/* Warning!  pointer arithmetic here that may not work with */
/*           multi-byte character sets!                     */


/* default template files for these conditions */

/*============================================================================
 * Define operational constants
 *===========================================================================*/
#define PRICESIZE		 40		 /* length of price				*/
#define CRCY_UNIT_LEN 3			/* max length of currency such as usd, yen */

#define MAXLINE 1024 

/*============================================================================
 * Merchant constants
 *===========================================================================*/

/*##########################################################
 * Constants to customize
 *##########################################################*/

/* --- Amount format, assuming 2 decimal places ---*/
extern THREAD const char _AmountFormat[];

/* Report failure by template exapnsion *AND* logging */
/* orderId may be null                                */
void ReportFailure(const char* message, const char* orderId, const char* templ);


/* EXPERSHOP: Remove this function
char *GenerateOrderId(char *orderid) ;
*/

/*
*****************************
* ValidatePrice
*
* Test the price string for syntactic validity.
* Check for acceptable currency
*
* INPUTS:
* The incoming price is not altered.
*
* OUTPUTS: 
* currencyOut - a string giving the ISO currency code for this price.
*         The string passed in must be at least 4 chars big.
* amountOut - a double that is the amount in a from you can calculate with.
* canonicalPrice - The price represented as the Cash Register 
*        would like to see it.  Format is: 'usd 9.99'
*        namely: a lower-case 3 letter ISO currency code,
*                a blank
*                at least one digit, a decimal point and two digits after that
*        The buffer you pass in has got to be at least a big as the largest 
*		 string you ever expect to see for an amount plus 5 spaces
*		 for the three character currency code, a blank and the null byte
*
* this returns CC_SUCCESS for OK, error code otherwise
*
*****************************
*/

int ValidatePrice (const char* priceIn, 
	char* currencyOut, double *amountOut, char* canonicalPrice);


/*
**********************************
* LoadPaymentInfo
*     paymentNVList 
*		= LoadPaymentInfo(orderId, query, paymentNVList, problemTemplate);
*
* Inputs:
*     orderId  -- order identifier... key to recovering payment info
*     query  -- pointer to the CGI input parameters
*     paymentNVList  -- pointer to the array of payment
*                          request arguments that we are building
*     problemTemplate -- template to use for error message if this fails
*
*  Returns paymentNVList
*          Notifies, logs then returns NULL if there is a problem
*  
*  This collects order related payment info and loads it into
*   the vector of payment arguments (paymentNVList)...
*   This sets a number of required and optional "mo." fields in the
*   payment request message.
*
* Our sample implementation gets the payment data from a flat file log
* It uses an orderId for the key.  This orderId is passed to the CGI as a query
*  parameter 
*
* Your implementation will probably store the payment data some other way.
***************************
*/

CCNVlistPtr LoadPaymentInfo (
	char* orderId, CCNVlistPtr query, CCNVlistPtr paymentNVList, 
	char* problemTemplate);

/* EXPERSHOP TBD ReadPaymentInfo for mswalletpay.c */
OrderRecPtr ReadPaymentInfo ( char* orderId, char* problemTemplate);


/****************
*  SendPayload dispenses a payload to the consumer.
*
* input: payload:  name of the file to dispense
*                  (this is open to customization...)
*        orderId:  the order ID
*        problemTemplate: template to use to report a failure, if one occurs
*
* returns: status
***************
*/
int SendPayload (char* payload, char* orderId, char *problemTemplate);

#ifdef __cplusplus
};
#endif
#endif
